#include <qlayout.h>
#include <qframe.h>

#include <klocale.h>
#include <kconfig.h>
#include <kapp.h>
#include <kglobal.h>
#include <kiconloader.h>

#include "configdialog.h"
#include "gestureconfigpage.h"
#include "generalconfigpage.h"

ConfigDialog::ConfigDialog(QWidget *parent, const char *name)
  : KDialogBase(KDialogBase::IconList, i18n("Configuration"),
		KDialogBase::Ok | KDialogBase::Apply | KDialogBase::Cancel,
		KDialogBase::Ok, parent, name, true, true),
    _generalPage(NULL), _gesturePage(NULL)
  {
  // The apply button will be enabled when something is modified
  enableButton(KDialogBase::Apply, false);

  QFrame *page = addVBoxPage(i18n("General"), QString::null,
			     KGlobal::iconLoader()->loadIcon("gear",
							 KIcon::Desktop));

  _generalPage = new GeneralConfigPage(page, "generalConfigPage");
  connect(_generalPage, SIGNAL(modified()), this, SLOT(slotModified()));

  
  
  page = addVBoxPage(i18n("Gestures"), QString::null,
		     KGlobal::iconLoader()->loadIcon("kgesture",
						     KIcon::Desktop));
  
  _gesturePage = new GestureConfigPage(page, "gestureConfigPage");
  _gesturePage->setMinimumSize(_gesturePage->sizeHint());
  connect(_gesturePage, SIGNAL(modified()),
	  this, SLOT(slotModified()));

  page->setMinimumSize(page->sizeHint());
  }

ConfigDialog::~ConfigDialog()
  {
  }

void ConfigDialog::readOptions(KConfig &config)
  {
  _generalPage->readOptions(config);
  _gesturePage->readOptions(config);
  }

void ConfigDialog::writeOptions(KConfig &config)
  {
  _generalPage->writeOptions(config);
  _gesturePage->writeOptions(config);
  }

void ConfigDialog::slotApply()
  {
  KConfig *config = kapp->config();
  writeOptions(*config);

  enableButton(KDialogBase::Apply, false);
  }

void ConfigDialog::slotOk()
  {
  slotApply();
  
  KDialogBase::slotOk();
  }

void ConfigDialog::slotModified()
  {
  enableButton(KDialogBase::Apply, true);
  }
